@@ -57,7 +57,7 @@ class JdbcConnection:
     def close(self):
         if self._connection.isClosed():
             raise Error('Connection already closed')
-        self.jconn.close()
+        self._connection.close()
 
     def commit(self):
         # TODO exception handling
@@ -283,7 +283,7 @@ class JdbcCursor:
             # sqlparams will not check for un-consumed keyword parameters
             # this is an error because the user is passing in arguments that are not being used by the query
             if len(params) < len(orig_params):
-                missing = [f'":{key}"' for key in orig_params if f':{key}' not in sql]
+                missing = ['":{}"'.format(key) for key in orig_params if ':{}'.format(key) not in sql]
                 raise ValueError('sql statement is missing named template paramaters:\n    ({})\n'
                                  'given paramaters:\n    {}\n'
                                  'in query:\n{}'.format(
@@ -394,7 +394,7 @@ class JdbcCursor:
 
     def executemany(self, operation, seq_of_parameters):
         """
-        Execute a many statements each with a different set of parameters
+        Execute many statements each with a different set of parameters
 
         :param operation: Sql text
         :param seq_of_parameters: a sequence of sequences containing parameters to pass into `operation`
